{#- OZI 0.1
# ozi/templates/new_child.j2
# SPDX-License-Identifier: Unlicense
-#}
{%- if project.fix == 'source' %}
{%- set folder = project.name %}
{%- elif project.fix == 'test' %}
{%- set folder = 'tests' %}
{%- elif project.fix == 'root' %}
{%- set folder = '.' %}
{%- endif %}
{{ '# OZI ' ~ spec.version }} meson.build:{{ project.fix }}_child_{{ parent }}
{%- for line in project.copyright_head.split('\n') %}
{{ '# ' ~ line }}
{%- endfor %}
{{ '# DO NOT EDIT BY HAND - This file was generated for use with OZI tools.' }}
{{ '# ozi-fix -> meson rewrite is the standard editing pipeline.' }}
{{ parent }}_files = [{%- if project.fix == 'source' %}'__init__.py'{% endif %}]
foreach file: {{ parent }}_files
    fs.copyfile(file)
    if not meson.is_subproject() or get_option('install-subprojects').enabled()
        python.install_sources(file, subdir: '{{ folder }}' / '{{ parent }}')
    endif
endforeach
if false
    executable('{{ parent }}_files', {{ parent }}_files)
endif
{{ parent }}_children = []
foreach child: {{ parent }}_children
    subdir(child)
endforeach
if false
    executable('{{ parent }}_children', {{ parent }}_children)
endif