{#- OZI 0.1
# ozi/templates/project.name/__init__.pyi.j2
# SPDX-License-Identifier: Unlicense
-#}
"""{{ project.name }} module stubfile"""
{%- for line in project.copyright_head.split('\n') %}
{{ '# ' ~ line }}
{%- endfor %}
{%- if user_template %}
{% extends user_template %}
{%- endif %}

